Check if DNAnexus is Initialized
dx_is_initialized.RdVerifies that the DNAnexus environment has been properly initialized. This function should be called before performing any DNAnexus operations.
dx_is_initialized.RdVerifies that the DNAnexus environment has been properly initialized. This function should be called before performing any DNAnexus operations.