Collapse Command Arguments
collapse_cmd_args.RdWhen submitting jobs to the Swiss Army Knife, this function is a convenience function to collapse the function arguments into a single call before submitting the call to [dx_run_swiss_army_knife()].
Examples
if (FALSE) { # \dontrun{
args <- "plink2"
cmd <- c("pfile", "ofh_data", "--make-bed", "--out", "ofh_data_bed")
collapse_cmd_args(args, cmd)
} # }