Check DNAnexus Path
dx_check_path.RdVerifies that the current working directory path in DNAnexus is valid and accessible. This function ensures that the cached path matches the current environment path.
dx_check_path.RdVerifies that the current working directory path in DNAnexus is valid and accessible. This function ensures that the cached path matches the current environment path.