Export Entities from DNAnexus
export_entities.RdSubmits table-exporter jobs to export OFH data entities from the DNAnexus project. This function submits one job per entity using the DNAnexus table-exporter app with customizable parameters.
Usage
export_entities(
dataset_or_cohort_or_dashboard = NULL,
output_prefix = "ofh_raw_phenotype_data",
output_format = "CSV",
coding_option = "RAW",
header_style = "FIELD-NAME",
priority = "low",
instance_type = "azure:mem2_ssd1_v2_x4",
project_id = NULL,
work_dir = "/",
entities = NULL
)Arguments
- dataset_or_cohort_or_dashboard
Character string specifying the dataset, cohort, or dashboard to export data from (The record ID is required, e.g. "record-ABCD123456DEFG")
- output_prefix
Character string specifying the prefix for output files
- output_format
Character string specifying the output format (default "CSV")
- coding_option
Character string specifying the coding option (default "RAW")
- header_style
Character string specifying the header style (default "FIELD-NAME")
- priority
Character string specifying job priority ("low", "normal", "high") (default "low")
- instance_type
Character string specifying the DNAnexus instance type (default "azure:mem2_ssd1_v2_x4")
- project_id
Character string specifying the DNAnexus project ID
- work_dir
Character string specifying the working directory in DNAnexus the files should be exported to, defaults to project directory saved in chache (get_dx_cache("dx_path"))
- entities
Character vector of entity names to export. If NULL (default), tries exports all possible OFH entities - entities not available will result in a failed job.